summaryrefslogtreecommitdiff
path: root/tests/regressiontests/multiple_database/tests.py
diff options
context:
space:
mode:
Diffstat (limited to 'tests/regressiontests/multiple_database/tests.py')
-rw-r--r--tests/regressiontests/multiple_database/tests.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/regressiontests/multiple_database/tests.py b/tests/regressiontests/multiple_database/tests.py
index 7f66ea3bcf..c688a8c64e 100644
--- a/tests/regressiontests/multiple_database/tests.py
+++ b/tests/regressiontests/multiple_database/tests.py
@@ -24,7 +24,7 @@ class QueryTestCase(TestCase):
multi_db = True
def test_db_selection(self):
- "Check that querysets will use the default databse by default"
+ "Check that querysets will use the default database by default"
self.assertEquals(Book.objects.db, DEFAULT_DB_ALIAS)
self.assertEquals(Book.objects.all().db, DEFAULT_DB_ALIAS)
@@ -1221,7 +1221,7 @@ class RouterTestCase(TestCase):
mark = Person.objects.using('default').create(pk=2, name="Mark Pilgrim")
# Now save back onto the usual databse.
# This simulates master/slave - the objects exist on both database,
# but the _state.db is as it is for all other tests.
pro.save(using='default')
@@ -1221,7 +1221,7 @@ class RouterTestCase(TestCase):
mark = Person.objects.using('default').create(pk=2, name="Mark Pilgrim")
- # Now save back onto the usual databse.
+ # Now save back onto the usual database.
# This simulates master/slave - the objects exist on both database,
# but the _state.db is as it is for all other tests.